@@ -22,4 +22,6 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-from .async_session import *
\ No newline at end of file
+from .async_session import (
+    Waifu,
+)
\ No newline at end of file
